pm4py.algo.conformance.alignments.decomposed package
====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.decomposed.variants

Submodules
----------

pm4py.algo.conformance.alignments.decomposed.algorithm module
-------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.decomposed.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.decomposed.parameters module
--------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.decomposed.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.decomposed
   :members:
   :undoc-members:
   :show-inheritance:
